YuroApp class
- Inheritance
Constructors
-
YuroApp({Key? key, required String title, GenerateAppTitle? onGenerateTitle, Color? color, TransitionBuilder? transitionBuilder, ThemeData? theme, ThemeData? darkTheme, ThemeData? highContrastTheme, ThemeData? highContrastDarkTheme, required YuroRoute routes, Locale fallbackLocale = const Locale('en', 'US'), Map<
String, Map< translations = const {}, Iterable<String, String> >LocalizationsDelegate> ? localizationsDelegates, LocaleListResolutionCallback? localeListResolutionCallback, LocaleResolutionCallback? localeResolutionCallback, Iterable<Locale> ? supportedLocales, bool debugShowCheckedModeBanner = true, bool debugShowMaterialGrid = false, bool showPerformanceOverlay = false, bool checkerboardRasterCacheImages = false, bool checkerboardOffscreenLayers = false, bool showSemanticsDebugger = false, Map<LogicalKeySet, Intent> ? shortcuts, Map<Type, Action< ? actions})Intent> >
Properties
-
actions
→ Map<
Type, Action< ?Intent> > -
final
- checkerboardOffscreenLayers → bool
-
final
- checkerboardRasterCacheImages → bool
-
final
- color → Color?
-
final
- darkTheme → ThemeData?
-
final
- debugShowCheckedModeBanner → bool
-
final
- debugShowMaterialGrid → bool
-
final
- fallbackLocale → Locale
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highContrastDarkTheme → ThemeData?
-
final
- highContrastTheme → ThemeData?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- localeListResolutionCallback → LocaleListResolutionCallback?
-
final
- localeResolutionCallback → LocaleResolutionCallback?
-
final
-
localizationsDelegates
→ Iterable<
LocalizationsDelegate> ? -
final
-
final
-
final
- onGenerateTitle → GenerateAppTitle?
-
final
- routes → YuroRoute
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortcuts
→ Map<
LogicalKeySet, Intent> ? -
final
- showPerformanceOverlay → bool
-
final
- showSemanticsDebugger → bool
-
final
-
supportedLocales
→ Iterable<
Locale> ? -
final
- theme → ThemeData?
-
final
- title → String
-
final
- transitionBuilder → TransitionBuilder?
-
final
-
translations
→ Map<
String, Map< String, String> > -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
builder(
BuildContext context, YuroAppController controller) → Widget -
override
-
createController(
) → YuroAppController -
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited