Observer<T> class
Constructors
-
Observer.fromFuture(Future<
T> fetchData) -
factory
Properties
- canceled ↔ bool
-
getter/setter pair
- completed ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onData
↔ ValueSetter<
T> -
latefinal
- onDone ↔ VoidCallback?
-
latefinal
-
onError
↔ ValueSetter<
String> ? -
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → Future< void> -
fetch(
{required ValueSetter< T> onData, ValueSetter<String> ? onError, VoidCallback? onDone}) → void -
listen(
{required ValueSetter< T> onData, ValueSetter<String> ? onError, VoidCallback? onDone}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited